soltools/mkdepend/main.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 652e4ee372e8939f48f69411b6326b237c6d9e4b
Author:     Stephan Bergmann <sberg...@redhat.com>
AuthorDate: Fri Jun 3 11:40:45 2022 +0200
Commit:     Stephan Bergmann <sberg...@redhat.com>
CommitDate: Fri Jun 3 13:23:49 2022 +0200

    Better use size_t for malloc_size
    
    ...as both malloc and read, to which this is passed, take arguments of type
    size_t, not unsigned
    
    Change-Id: I2b114c4e67bc9317d908d613fda607a12cf22579
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/135347
    Tested-by: Jenkins
    Reviewed-by: Stephan Bergmann <sberg...@redhat.com>

diff --git a/soltools/mkdepend/main.c b/soltools/mkdepend/main.c
index b8b84b453476..58633c830115 100644
--- a/soltools/mkdepend/main.c
+++ b/soltools/mkdepend/main.c
@@ -473,7 +473,7 @@ struct filepointer *getfile(char *file)
     struct stat st;
     off_t       size_backup;
     ssize_t     bytes_read;
-    unsigned    malloc_size;
+    size_t      malloc_size;
 
     content = (struct filepointer *)malloc(sizeof(struct filepointer));
     if ((fd = open(file, O_RDONLY)) < 0) {
@@ -486,7 +486,7 @@ struct filepointer *getfile(char *file)
 
     size_backup = st.st_size;
     malloc_size = size_backup;
     /* Since off_t usually is larger than unsigned, need to test for
      * truncation.
      */
     if ( (off_t)malloc_size != size_backup )
@@ -486,7 +486,7 @@ struct filepointer *getfile(char *file)
     size_backup = st.st_size;
     malloc_size = size_backup;
-    /* Since off_t usually is larger than unsigned, need to test for
+    /* Since off_t usually is larger than size_t, need to test for
      * truncation.
      */

Reply via email to